package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(``P`!````$*8$"#0````XH@```````#0`(``,
M`"@`'``;``8````T````-(`$"#2`!`B``0``@`$```0````$`````P```+0!
M``"T@00(M($$"!,````3````!`````$````!``````````"`!`@`@`0(]!``
M`/00```$`````!````$`````(````*`$"`"@!`A@+P``8"\```4`````$```
M`0````!0````T`0(`-`$"/!$``#P1```!``````0```!````W)X``-PN!0C<
M+@4(+`(``)@2```&`````!````(```#DG@``Y"X%".0N!0@(`0``"`$```8`
M```$````!````,@!``#(@00(R($$"&P```!L````!`````0```!3Y71D[`$`
M`.R!!`CL@00(*````"@````$````!````%#E=&0PCP``,`\%"#`/!0C4````
MU`````0````$````4>5T9```````````````````````````!@```!````!2
MY71DW)X``-PN!0C<+@4()`$``"0!```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`/E`-D"XL\%,/G)31F![DJEH'9IC!```
M`!@````%````1TY5``$``<`$`````0````(``<`$`````0````0````0````
M`0```$=.50```````P````(`````````$0```#X````(````"``````<``0E
M0`2"*`$``:"&`8C``0`"2R@$*#B",D.*```(/@```#\```!"````10```$8`
M``!,````3@```%````!3````5`````````!5````6````%D```!:````````
M``````![\$IK;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP,+E/RRZXY)\^Z%L8&H)0]:'^9R!9J_,9L6YG$`X\HL<0D75[(D'<-/)
MU;)Q,V+;[0PZEPM8Z.WLI]VC:W^IG)OAIP(*"HH05Z/@^TD`````````````
M````````IP(`````````````$@```,L"`````````````!(```"X`@``````
M```````2````Y0``````````````$@```&```````````````!(```#G`0``
M```````````2````;`$`````````````$@```#H"`````````````!(````L
M`@`````````````2`````0``````````````(````!$"`````````````!(`
M``"L`0`````````````2````W`(`````````````$@```"P!````````````
M`!(```"!```````````````2````'`$`````````````$@````X!````````
M`````!(```"^`@`````````````2````V@$`````````````$@```(H!````
M`````````!(```#J```````````````2````_`$`````````````$@```)("
M`````````````!(````#`@`````````````2````$```````````````$@``
M`"T``````````````!8```"]```````````````2````40``````````````
M$@```'<"`````````````!(```!/`@`````````````2````)0(`````````
M````$@```)\#`````````````!(```"A```````````````2````]0$`````
M````````$@```$X!`````````````!(```"(`@`````````````2````"P(`
M````````````$@```$`!`````````````!(```!(`@`````````````2````
M@P$`````````````$@```,X``````````````!(```#O```````````````2
M````70(`````````````$@```+L!`````````````!(````>`@``````````
M```2````D0(`````````````$@```&X"`````````````!(```"D`0``````
M```````2````;```````````````$@```'<!`````````````!(```"9`@``
M```````````2````5@(`````````````$@```-\!`````````````!(````U
M`0`````````````2````'@``````````````$@```$$"`````````````!(`
M``#!`0`````````````2````LP$`````````````$@```-,!````````````
M`!(````9`@`````````````2````CP``````````````$@```%P!``#0H00(
M`````!(```"H`P``'LX$".H````2``X`V@,``.6_!`@?"P``$@`.`,X!```@
MI`0([@$``!(`#@`B`P``>;@$"`4````2``X`1P,```3+!`@:`P``$@`.```$
M``!^N`0(QP$``!(`#@#)`P``"#$%"``````0`!D`,P,``$6Z!`@@````$@`.
M`%T#``"*O@0(7````!(`#@"5`0``!-`$"`0````1`!``P0,``':W!`@O````
M$@`.`-4#``!T004(`````!``&0#N`P```+\$".4````2``X`M`,``/@P!0@`
M````$``8`$````#@H00(`````!(```"!`P``9;H$",P````2``X`T@(``#`Q
M!0@$````$0`9`($"```@,04(!````!$`&0#G`P``"#$%"``````0`!@`#00`
M``0Q!0@$````$0`8`/L```#0H`0(`````!(```"Z`P``$*8$"#$````2``X`
MM@,``/@P!0@`````(``8`$`#````T`0(!````!$`$`#4`@``,#$%"`0````A
M`!D`C0,``.:^!`@:````$@`.`&L#``"EMP0(U````!(`#@"P````0#$%"`$`
M```1`!D`%P0``#&[!`A9`P``$@`.``!?7V=M;VY?<W1A<G1?7P!097)L7W-Y
M<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA
M9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA
M9W,`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S
M970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L
M7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F
M97-Y<VUA;&QO8P!P97)L7V%L;&]C`%])3U]S=&1I;E]U<V5D`&UE;6UO=F4`
M<W1R8VAR`&QS965K-C0`<FUD:7(`7U]L:6)C7W-T87)T7VUA:6X`<W1R8VUP
M`')E860`<W1R;F-M<`!?7W-T<FYC<'E?8VAK`&=E='5I9`!A8V-E<W,`;W!E
M;F1I<@!C;&]S90!R96%L;&]C`&5X:70`<W1R=&]K`'5N;&EN:P!?7V9P<FEN
M=&9?8VAK`&]P96XV-`!S=')D=7``<W1R<W1R`'-T<FQE;@!M96UC:'(`7U]S
M=&%C:U]C:&M?9F%I;`!R96%D;&EN:P!R96%D9&ER-C0`<W1D97)R`&-L;W-E
M9&ER`&QS=&%T-C0`7U]S<')I;G1F7V-H:P!?7V5R<FYO7VQO8V%T:6]N`&UK
M9&ER`%]?;65M8W!Y7V-H:P!G971P:60`7U]E;G9I<F]N`%]?<F5G:7-T97)?
M871F;W)K`&QI8G!E<FPN<V\N-2XS-BXP`&QI8FTN<V\N-@!L:6)C+G-O+C8`
M;&EB8W)Y<'0N<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?
M9G!?:'<`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!X<U]I;FET
M`%]?8G-S7W-T87)T`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T
M=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N
M=@!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"0U\R+C(`1TQ)0D-?,BXS,P!'
M3$E"0U\R+C,N,@!'3$E"0U\R+C$`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP`"]U
M<W(O;&EB+W!E<FPU+S4N,S8N,"]I-C@V+7!L9"UL:6YU>"UT:')E860M;75L
M=&DO0T]210`````"``(``@`!``$``P`!``0``P`!``(``@`%``$``0`!``$`
M`P`"``$``@`"``8``@`!``$``0`!``<``@`"``(``0`"``$``@`"``$``@`"
M``$``0`(``(``@`&``(``@`!``$``P`"``(``0`!``(`"0`$``(``@`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``(``0`!``$``0`!
M``$``@`!``$``0`!`````0`(``H#```0`````````+21E@8```D`)`0``!``
M```4:6D-```(`"\$```0````$FEI#0``!P`Y!```$````+.1E@8```8`0P0`
M`!````!R&6D)```%`$X$```0````$6EI#0``!`!:!```$````'09:0D```,`
M9`0``!`````0:6D-```"`'`$````````["\%"`8*``#P+P4(#AH``"`Q!0@%
M4```,#$%"`5/``!`,04(!5H````P!0@'`0``!#`%"`<"```(,`4(!P,```PP
M!0@'!```$#`%"`<%```4,`4(!P8``!@P!0@'!P``'#`%"`<(```@,`4(!PD`
M`"0P!0@'4P``*#`%"`<+```L,`4(!PP``#`P!0@'#0``-#`%"`<.```X,`4(
M!P\``#PP!0@'$```0#`%"`<1``!$,`4(!Q(``$@P!0@'$P``3#`%"`<4``!0
M,`4(!Q4``%0P!0@'%@``6#`%"`<7``!<,`4(!Q@``&`P!0@'&0``9#`%"`<^
M``!H,`4(!TT``&PP!0@'&P``<#`%"`<<``!T,`4(!QT``'@P!0@''@``?#`%
M"`<?``"`,`4(!R```(0P!0@'(0``B#`%"`<B``",,`4(!R,``)`P!0@')```
ME#`%"`<E``"8,`4(!R8``)PP!0@')P``H#`%"`<H``"D,`4(!RD``*@P!0@'
M*@``K#`%"`<K``"P,`4(!RP``+0P!0@'+0``N#`%"`<N``"\,`4(!R\``,`P
M!0@',```Q#`%"`<Q``#(,`4(!S(``,PP!0@',P``T#`%"`<T``#4,`4(!S4`
M`-@P!0@'-@``W#`%"`<W``#@,`4(!S@``.0P!0@'.0``Z#`%"`<Z``#L,`4(
M!SL``/`P!0@'/```]#`%"`<]````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[[4X/L".A#!@``@</GCP``BX/X____A<!T`O_0@\0(6\,`````````
M``````#_-?@O!0C_)?PO!0@`````_R4`,`4(:`````#IX/____\E!#`%"&@(
M````Z=#_____)0@P!0AH$````.G`_____R4,,`4(:!@```#IL/____\E$#`%
M"&@@````Z:#_____)10P!0AH*````.F0_____R48,`4(:#````#I@/____\E
M'#`%"&@X````Z7#_____)2`P!0AH0````.E@_____R4D,`4(:$@```#I4/__
M__\E*#`%"&A0````Z4#_____)2PP!0AH6````.DP_____R4P,`4(:&````#I
M(/____\E-#`%"&AH````Z1#_____)3@P!0AH<````.D`_____R4\,`4(:'@`
M``#I\/[___\E0#`%"&B`````Z>#^____)40P!0AHB````.G0_O___R5(,`4(
M:)````#IP/[___\E3#`%"&B8````Z;#^____)5`P!0AHH````.F@_O___R54
M,`4(:*@```#ID/[___\E6#`%"&BP````Z8#^____)5PP!0AHN````.EP_O__
M_R5@,`4(:,````#I8/[___\E9#`%"&C(````Z5#^____)6@P!0AHT````.E`
M_O___R5L,`4(:-@```#I,/[___\E<#`%"&C@````Z2#^____)70P!0AHZ```
M`.D0_O___R5X,`4(:/````#I`/[___\E?#`%"&CX````Z?#]____)8`P!0AH
M``$``.G@_?___R6$,`4(:`@!``#IT/W___\EB#`%"&@0`0``Z<#]____)8PP
M!0AH&`$``.FP_?___R60,`4(:"`!``#IH/W___\EE#`%"&@H`0``Z9#]____
M)9@P!0AH,`$``.F`_?___R6<,`4(:#@!``#I</W___\EH#`%"&A``0``Z6#]
M____):0P!0AH2`$``.E0_?___R6H,`4(:%`!``#I0/W___\EK#`%"&A8`0``
MZ3#]____);`P!0AH8`$``.D@_?___R6T,`4(:&@!``#I$/W___\EN#`%"&AP
M`0``Z0#]____);PP!0AH>`$``.GP_/___R7`,`4(:(`!``#IX/S___\EQ#`%
M"&B(`0``Z=#\____)<@P!0AHD`$``.G`_/___R7,,`4(:)@!``#IL/S___\E
MT#`%"&B@`0``Z:#\____)=0P!0AHJ`$``.F0_/___R78,`4(:+`!``#I@/S_
M__\EW#`%"&BX`0``Z7#\____)>`P!0AHP`$``.E@_/___R7D,`4(:,@!``#I
M4/S___\EZ#`%"&C0`0``Z4#\____)>PP!0AHV`$``.DP_/___R7P,`4(:.`!
M``#I(/S___\E]#`%"&CH`0``Z1#\__]5B>575E.#Y/"#[$"+10R)1"0LBT40
MB40D*&6A%````(E$)#PQP(U$)"B)1"0(C40D+(E$)`2-10B)!"3H3____\=$
M)`C0H`0(QT0D!-"@!`C'!"3@H00(Z(LJ``"`/4`Q!0@`#X0``0``H?`O!0AE
MBP"`B)H"```#BT4(@\`%/?___S\/ATX!```!P`'`B00DZ*K^__^)QJ-D004(
MBUPD+(L#B0;'1@3,T00(H00Q!0B)1@C'1@S/T00(QP5H004(!````(M]"(/_
M`7X;C4,$C580C0P_`<D!RXL(B0J#P`2#P@0YPW7RQT2^#`````#'1"00````
M`(ET)`R#QP.)?"0(QT0D!!&W!`BA<$$%"(D$).AH^___B<.%P'1VH7!!!0B)
M!"3H5?W__XU4)#BXI]`$".C!#```A<!T:Z%P004(B00DZ`;[___H4?S__XM$
M)#QE*P44````#X6)````B=B-9?1;7E]=P^CA^___HW!!!0B%P'1EB00DZ&#\
M__^A\"\%"&6+$,:"0P8```#IV_[__Z%P004(B00DZ$_[__^)P^EV____H6Q!
M!0B%P'0*B00DZ$4H``#K@HU4)#BX7-`$".@Q#```HVQ!!0B%P`^$9____^O9
MZ-/\___'!"0!````Z/?]___HXOS__V:0\P\>^S'M7HGA@^3P4%12Z!D```"!
MP]")``!J`&H`45;'P""D!`A0Z)3]___TBQPDP_,/'OO#9I!FD&:09I!FD(L<
M),.X"#$%"#T(,04(=!RX`````(7`=!-5B>6#[!C'!"0(,04(_]")[%W#P[@(
M,04(+0@Q!0B)PL'Z`L'H'P'0T?AT(+H`````A=)T%U6)Y8/L&(E$)`3'!"0(
M,04(_]*)[%W#PX`]03$%"`!U%E6)Y8/L".B*____Q@5!,04(`8GL7</#ZZ5F
MD&:09I!FD%575E.!['P!``")P8E$)`AEH10```")A"1L`0``,<"+5($<#\J)
M5(0L@\`!@_@0=>Z-5"0LC8PD+`$``(M"-#-"(#-""#,"T<")0D"#P@0YRG7I
MBW0D"(L>BWX$BVX(BTX,BT80B40D'`-$)"P%F7F"6HG:P<(%`=")ZC'*(?J)
MSC'*`=")?"00B?K!R@*)Z3'1B=\AV3'IB70D&(M<)#`!\X'#F7F"6@'+B<'!
MP04!RXE\)`R)^<')`HG.B=$Q\2'!,=&);"04BWPD-`'O@<>9>8):`?F)W<'%
M!0'IP<@"B?4QQ8GO(=\Q]P-4)#B!PIEY@EH!^HG-P<4%`>K!RP*)Q3'=B>\A
MSS''`W0D/('&F7F"6@'^B=7!Q04![L')`HG=,<V)[R'7,=\#1"1`!9EY@EH!
M^(GUP<4%`>C!R@*)S3'5B>\A]S'/`UPD1('#F7F"6@'[B<7!Q04!Z\'.`HG5
M,?6)[R'',=<#3"1(@<&9>8):`?F)W<'%!0'IP<@"B?4QQ8GO(=\Q]P-4)$R!
MPIEY@EH!^HG-P<4%`>K!RP*)Q3'=B>\ASS''`W0D4('&F7F"6@'^B=7!Q04!
M[L')`HG=,<V)[R'7,=\#1"14!9EY@EH!^(GUP<4%`>C!R@*)S3'5B>\A]S'/
M`UPD6('#F7F"6@'[B<7!Q04!Z\'.`HG5,?6)[R'',=<#3"1<@<&9>8):`?F)
MW<'%!0'IP<@"B?4QQ8GO(=\Q]P-4)&"!PIEY@EH!^HG-P<4%`>K!RP*)Q3'=
MB>\ASS''`W0D9('&F7F"6@'^B=7!Q04![L')`HG=,<V)[R'7,=\#1"1H!9EY
M@EH!^(GUP<4%`>C!R@*)S3'5B>\A]S'/`UPD;('#F7F"6@'[B<7!Q04!Z\'.
M`HG5,?6)[R'',=<#3"1P@<&9>8):`?F)W<'%!0'IP<@"B?4QQ8GO(=\Q]P-4
M)'2!PIEY@EH!^HG-P<4%`>K!RP*)Q3'=B>\ASS''`W0D>('&F7F"6@'WB=7!
MQ04![\')`@-$)'P%H>O9;HG=,<V)[C'6`<:)_<'%!0'NP<H"`YPD@````(V#
MH>O9;HG+,=,Q^P'#B?7!Q04!ZXG]P<T"B>@#C"2$````C;FAZ]ENB=$QZ3'Q
M`?F)W<'%!0'IP<X"`Y0DB````(VZH>O9;HG",?(QV@'ZB<W!Q04!ZL'+`@.$
M)(P```"-N*'KV6Z)]3'=B>@QR`'XB=7!Q04!Z,')`@.T))````"-OJ'KV6Z)
MW3'-B>XQU@'^B<7!Q04![L'*`@.<))0```"-NZ'KV6Z)RS'3,<,!^XGUP<4%
M`>O!R`(#C"28````C;FAZ]ENB=$QP3'Q`?F)W<'%!0'IP<X"`Y0DG````(VZ
MH>O9;HG",?(QV@'ZB<W!Q04!ZL'+`@.$)*````"-N*'KV6Z)]3'=B>@QR`'X
MB=7!Q04!Z,')`@.T)*0```"-OJ'KV6Z)W3'-B>XQU@'^B<7!Q04![L'*`@.<
M)*@```"-NZ'KV6Z)RS'3,<,!^XGUP<4%`>O!R`(#C"2L````C;FAZ]ENB=$Q
MP3'Q`?F)W<'%!0'IP<X"`Y0DL````(VZH>O9;HG",?(QV@'ZB<W!Q04!ZL'+
M`@.$)+0```"-N*'KV6Z)]3'=B>@QR`'XB=7!Q04!Z,')`@.T)+@```"-OJ'K
MV6Z)W3'-B>XQU@'^B<7!Q04![L'*`@.<)+P```"-NZ'KV6Z)RS'3,<,!^XGU
MP<4%`>O!R`(#C"3`````C;FAZ]ENB=$QP3'Q`?F)W<'%!0'IP<X"`Y0DQ```
M`(VZH>O9;HG",?(QV@'ZB<W!Q04!ZL'+`@.$),@```"-N*'KV6Z)]3'=B>@Q
MR`'XB=7!Q04!Z,')`HG="<TAU8G?(<\)[P.T),P```"![B1#Y'`!]XG%P<4%
M`>_!R@*)S0G5(<6)SB'6">X#G"30````@>LD0^1P`=Z)^\'#!0'>P<@"B=4)
MQ2']B=,APPGK`XPDU````('I)$/D<`'+B?'!P04!R\'/`HG%"?TA]8G!(?D)
MZ0.4)-@```"!ZB1#Y'`!T8G:P<(%`='!S@*)_0GU(=V)^B'R">H#A"3<````
M+21#Y'`!PHG-P<4%`>K!RP*)]0G=(<V)\"'8">@#O"3@````@>\D0^1P`?B)
MU<'%!0'HP<D"B=T)S2'5B=\ASPGO`[0DY````('N)$/D<`'^B<7!Q04![L'*
M`HG-"=4AQ8G/(=<)[P.<).@```"!ZR1#Y'`!^XGUP<4%`>O!R`*)U0G%(?6)
MUR''">\#C"3L````@>DD0^1P`?F)W<'%!0'IP<X"B<4)]2'=B<<A]PGO`Y0D
M\````('J)$/D<`'ZB<W!Q04!ZL'+`HGU"=TAS8GW(=\)[P.$)/0````M)$/D
M<`'XB=7!Q04!Z,')`HG="<TAU8G?(<\)[P.T)/@```"![B1#Y'`!_HG%P<4%
M`>[!R@*)S0G5(<6)SR'7">\#G"3\````@>LD0^1P`?N)]<'%!0'KP<@"B=4)
MQ2'UB=<AQPGO`XPD``$``('I)$/D<`'YB=W!Q04!Z<'.`HG%"?4AW8G'(?<)
M[P.4)`0!``"!ZB1#Y'`!^HG-P<4%`>K!RP*)]0G=(<V)]R'?">\#A"0(`0``
M+21#Y'`!^(G5P<4%`>C!R0*)W0G-(=6)WR'/">\#M"0,`0``@>XD0^1P`?Z)
MQ<'%!0'NP<H"B<T)U2'%B<\AUPGO`YPD$`$``('K)$/D<`'[B?7!Q04!Z\'(
M`HG5"<4A]8G7(<<)[P.,)!0!``"!Z21#Y'`!^8G=P<4%`>G!S@*)Q0GU(=V)
MQR'W">\#E"08`0``@>HD0^1P`?J)S<'%!0'JP<L"`X0D'`$``"TJ/ITUB?4Q
MW8GO,<\!QXG5P<4%`>_!R0(#M"0@`0``@>XJ/ITUB=TQS8GH,=`!\(G]P<4%
M`>C!R@*)U@.<)"0!``"-D];!8LJ)RS'S,?L!TXG"P<(%`=/!SP(#C"0H`0``
M@>DJ/ITUB?(Q^C'"`<J)V<'!!0'*B<'!R0(#M"0L`0``C8;6P6+*B?TQS8GN
M,=X!QHG5P<4%`>[!RP(#O"0P`0``@>\J/ITUB<TQW8GH,=`!^(GUP<4%`>C!
MR@*)UP.,)#0!``"-D=;!8LJ)V3'Y,?$!T8G"P<(%`='!S@(#G"0X`0``@>LJ
M/ITUB?HQ\C'"`=J)R\'#!0':B</!RP(#O"0\`0``C8?6P6+*B?4QW8GO,<\!
MQXG5P<4%`>_!R0(#M"1``0``@>XJ/ITUB=TQS8GH,=`!\(G]P<4%`>C!R@*)
MU@.<)$0!``"-D];!8LJ)RS'S,?L!TXG"P<(%`=/!SP(#C"1(`0``@>DJ/ITU
MB?(Q^C'"`<J)V<'!!0'*B<'!R0(#M"1,`0``C8;6P6+*B?TQS8GN,=X!QHG5
MP<4%`>[!RP(#O"10`0``@>\J/ITUB<TQW8GH,=`!^(GUP<4%`>C!R@(#C"14
M`0``@>DJ/ITUB=TQU8GO,?<!SXG!P<$%`<_!S@(#G"18`0``@>LJ/ITUB=$Q
M\3'!`=F)^\'#!0'9P<@"`Y0D7`$``('J*CZ=-8GS,<,Q^P'3B<K!P@4!T\'/
M`@.T)&`!``"![BH^G36)PC'Z,<H!\HG=P<4%`>K!R0(#A"1D`0``C;#6P6+*
MB?TQS8GH,=@!\(G5P<4%`>C!RP*+;"0,`ZPD:`$``(GN@>XJ/ITU`?>)S3'=
MB>XQU@'^B<7!Q04![HM\)`B)-P-$)!")_HE'!,'*`HM\)!2-!#J)1@B+1"08
M`=B)1@R+1"0<`<B)1A"+A"1L`0``92L%%````'4+@<1\`0``6UY?7</HUO#_
M_U575E.#["R)5"0<A<`/A(<```")QJ$P,04(B40D&(7`='@/M@:$P'0$/#UU
M.3'MBWPD&(L?A=MT(XEL)`B)="0$B1PDZ"WQ__^%P'4&@#PK/70I@\<$BQ^%
MVW7=B=B#Q"Q;7E]=PXGQ@\$!#[8!A,!T!#P]=?(I\8G-Z[.)^BM4)!C!^@*+
M1"0<B1"-30$!RXG8@\0L6UY?7<,QVXG8@\0L6UY?7<-55U93@>R<````B<-E
MH10```")A"2,````,<"%VW0%@#L`=1^+A"2,````92L%%`````^%"@$``('$
MG````%M>7UW#B1PDZ*7N__^)QH7`=-.)-"3H]^[__X7`#X2G````C7@3@'@3
M+G4&@'\!`'3A@'@3+@^$HP```(D<).C>[O__B<6)/"3HU.[__P'%@\4"B2PD
MZ&?O__^)Q8E\)!2)7"00QT0D#`C0!`C'1"0(_____\=$)`0!````B00DZ.WO
M__^-1"0LB40D!(DL).@-[O__@_C_=!"+1"0\)0#P```]`$```'1.B2PDZ(#N
M__^)+"3HR.W__XDT).A0[O__A<`/A5G___^)-"3HL.[__XD<).@H[___Z0?_
M__^`?P$N#X53____@'\"``^$(/___^E$____B>CHP_[__XUV`.NNZ.GN__]3
M@>R(````B<-EH10```")1"1\,<"-1"0<B40D!(D<).CT[O__A<!U-(M4)"R!
MX@#P``"!^@!```!T"('Z`*```'4<QT0D!`(```")'"3H-NW__X7`#Y3`#[;`
MZP(QP(M4)'QE*Q44````=0B!Q(@```!;P^AP[O__55=64X'L+!```(G#B=9E
MH10```")A"0<$```,<#'1"0(_P\``(U\)!R)?"0$QP0D#M`$".AW[O__A<!^
M1(UH_X!\!!L`=6V%[70VB6PD",=$)`0O````B3PDZ*'N__^%P'0>B6PD#(E\
M)`B)7"0$H?`O!0AEBP")!"3H4>W__^L8B70D"(E<)`2A\"\%"&6+`(D$).@G
M[/__BX0D'!```&4K!10```!U#X'$+!```%M>7UW#B<7KD^BS[?__55=64X/L
M/(G'B=-EH10```")1"0L,<"`.CUU`X/#`8D<).B\[/__B<6-5"0HB?CHJ?S_
M_XG&A<`/A,X```")!"3HG>S__SG%#X:L````BU0D*`'2`=(/M@>$P`^$6P$`
M`#P]#X13`0``B?B#P`$/M@B$R70%@/D]=?$I^(G6B50D%`,U,#$%"(/%`@'%
MB2PDZ.[L__^)!H7`=$:A,#$%"(M4)!2+%!"-3P$/M@>(`H3`=!H\/74&ZQ2$
MP'00@\(!@\$!#[9!_X@"/#UU[,8"/3'`#[8,`XA,`@&#P`&$R77QBT0D+&4K
M!10````/A=T```"#Q#Q;7E]=PS'`#[84`X@4!H/``832=?+KU8L-,#$%"(LQ
MA?8/A*<````Q]HGP@\8!BQ2QA=)U](/``P'``<"+%6!!!0B%TG5=B4PD',<%
M8$$%"`$```")!"3H,NS__XE$)!2%P'2(C10V`=*)5"0(B50D&(M,)!R)3"0$
MB00DZ(WL__^+1"04HS`Q!0B+5"08BT0D%,=$L`0`````B70D*.F^_O__B40D
M!(D,).C_Z?__B40D%*,P,04(A<`/A"S___^-%#8!TNO',<#IN?[__[@(````
M,?;I8O___^C?Z___4X/L*,=$)`SXT00(QT0D"-"A!`C'1"0$'=`$"(L=\"\%
M"&6+`XD$).AB[/__QT0D%`````#'1"00J=$$",=$)`RIT00(QT0D"`3+!`C'
M1"0$.=`$"&6+`XD$).A_ZO__@\0H6\.#[!S'1"0,^-$$",=$)`C0H00(QT0D
M!!W0!`BA\"\%"&6+`(D$).C_Z___@\0<PU=64X'L,"```&6A%````(F$)"P@
M```QP.B.Z/__QT0D%!G0!`B)1"00QT0D#$[0!`C'1"0(`1```,=$)`0!````
MC5PD*HD<).A^Z___QT0D"``0``"-M"0K$```B70D!(D<).@CZ___A<!X7XG#
MC4`!B00DZ*+J__^%P'05B<>#^P1S.?;#`G4F]L,!=1[&!!@`BY0D+"```&4K
M%10```!U+8'$,"```%M>7\.DZ]]FI?;#`738C70F`)#K[XG9P>D"\Z7VPP)T
MP.OD,<#KP^AWZO__Z2?___]55U93@>RL$```B[PDP!```(NT),00``!EH10`
M``")A"2<$```,<"-;"0\B>JX7-`$".AE^?__B</'1"0$+P```(D\).@IZ/__
MA<!T+8GZN&70!`CH9OS__XGXBY0DG!```&4K%10````/A5`!``"!Q*P0``!;
M7E]=PXD\).@@Z?__B40D+,=$)`1RT`0(B30DZ/SI__^)QH7`=+&+1"0L@\`!
MB40D+(`^``^$P@```(7;=!2)="0$B1PDZ++J__^%P`^$@P```(DT).C2Z/__
M@'P&_R]U#H/H`<8$!@"`?`;_+W3R`T0D+#W_#P``#X]9____B7PD&,=$)!1T
MT`0(B70D$,=$)`Q?T00(QT0D"``0``#'1"0$`0```(VT))P```")-"3HQ^G_
M_XEL)`2)-"3HZ^?__X7`=1"+1"1,)0#P```]`(```'1'QT0D!'+0!`C'!"0`
M````Z#/I__^)QH7`#X3D_O__@#X`#X4^____A=MT!8`[+G0/OEK0!`BX`0``
M`.E;____@'L!`'2[Z^G'1"0$`0```(DT).APY___A<!UI8GRN&70!`CH#?O_
M_XDT).B(Z?__Z9S^__^-=@#HJ^C__XM$)`0/MA")P832=!"#P`&`^B\/1,@/
MMA"$TG7PB<C#4X/L&(M<)""%VP^$G````(`[``^$DP```(D<).B:Y___@^@!
M`=@YPW(,Z8X```"#Z`$YPW0>@#@O9I!T\CG#<WR#Z`$YPW0,@#@O="*#Z`$Y
MPW7T@#LO=%/'1"0@=-`$"(/$&%OI\>C__X`X+W4'@^@!.<-R]"G8C5`"@?H`
M$```=T#'1"0,`!```(/``8E$)`B)7"0$QP0D8#$%".B)Y?__N&`Q!0B#Q!A;
MP\=$)"!:T`0(@\086^F>Z/__.<-UKNN1,<"#Q!A;9I##5U:#[#1EH10```")
M1"0L,<`/MP74T00(9HE$)`J-?"0,OM;1!`BX(````(G!P>D"\Z6H`G0"9J6-
M5"0$N';0!`CHH_;__X7`="6+1"0$`<`!P`,%,#$%"(M0!(D0A=)TUX/`!(M0
M!(D0A=)U].O)C50D!+A_T`0(Z&SV__^%P'0EBT0D!`'``<`#!3`Q!0B+4`2)
M$(72=->#P`2+4`2)$(72=?3KR8U4)`2XA]`$".@U]O__A<!T)8M$)`0!P`'`
M`P4P,04(BU`$B1"%TG37@\`$BU`$B1"%TG7TZ\F-5"0$N)#0!`CH_O7__X7`
M="6+1"0$`<`!P`,%,#$%"(M0!(D0A=)TUX/`!(M0!(D0A=)U].O)C50D!+B7
MT`0(Z,?U__^%P'0EBT0D!`'``<`#!3`Q!0B+4`2)$(72=->#P`2+4`2)$(72
M=?3KR8U4)`2XI]`$".B0]?__A<!T)8M$)`0!P`'``P4P,04(BU`$B1"%TG37
M@\`$BU`$B1"%TG7TZ\F-5"0$N%S0!`CH6?7__X7`="6+1"0$`<`!P`,%,#$%
M"(M0!(D0A=)TUX/`!(M0!(D0A=)U].O)C50D!+BST`0(Z"+U__^%P'0EBT0D
M!`'``<`#!3`Q!0B+4`2)$(72=->#P`2+4`2)$(72=?3KR8U4)`2XO=`$".CK
M]/__A<!T)8M$)`0!P`'``P4P,04(BU`$B1"%TG37@\`$BU`$B1"%TG7TZ\F-
M5"0$N,?0!`CHM/3__X7`="6+1"0$`<`!P`,%,#$%"(M0!(D0A=)TUX/`!(M0
M!(D0A=)U].O)C50D!+AET`0(Z'WT__^%P'0EBT0D!`'``<`#!3`Q!0B+4`2)
M$(72=->#P`2+4`2)$(72=?3KR8U4)`2XT=`$".A&]/__B<*%P'0*N+W0!`CH
M6??__XU4)`2XXM`$".@H]/__B<*%P'0*N/30!`CH._?__XU4)`2X_]`$".@*
M]/__B<*%P'0LN%S0!`CH'??__[HKT00(N)?0!`CH#O?__XM$)"QE*P44````
M=4F#Q#1>7\.-5"0$N`_1!`CHRO/__XG"A<!T#+BST`0(Z-WV___KOH%\)!M0
M05)?=;2!?"0?0TQ%076J9H%\)"-./76AC50D)>O1Z&;D__^#[!QEH10```")
M1"0,H0`Q!0B#^/]T$8M4)`QE*Q44````=3.#Q!S#C50D"+BST`0(Z%KS__^%
MP'09#[8`/#`/E<*$P`^5P`^VP"'0HP`Q!0CKQ#'`Z_7H"N3__X/L'.ARX___
MB00DZ$KC__^%P'0"BP"#Q!S#5U93@^PPBW0D0&6A%````(E$)"PQP(U4)"BX
MJ=$$".CV\O__A<!T!XG#@#@`=2.+1"0L92L%%`````^%FP```(GRN*G1!`B#
MQ#!;7E_IZ_7__XET)`2)!"3H4N/__X7`=!2+1"0L92L%%````'5L@\0P6UY?
MPXDT).BBXO__B<>)'"3HF.+__P''@\<"B3PDZ"OC__^)QXE<)!C'1"04<M`$
M"(ET)!#'1"0,7]$$",=$)`C_____QT0D!`$```")!"3HJ>/__XM$)"QE*P44
M````=0>)^NEG____C70F`)#H"^/__U575E.![)R!``"+O"2P@0``9:$4````
MB80DC($``#'`QX0DO````#G1!`C'A"3`````6M`$",>$),0`````````QX0D
MV````.W0!`C'A"3<````/M$$",>$).`````*T00(QX0DY````$;1!`C'A"3H
M`````````,>$),@````MT00(QX0DS````$K1!`C'A"30`````````(U4)%RX
M7-`$".B.\?__A<!T"8`X``^%,00``.C"X?__B00DZ)KA__^%P`^$@`,``(LP
MA?8/A'8#``")-"3H8.'__P'`@\`!B00DZ//A__^)PP^V!H3`=#:)W0^VP(E$
M)!#'1"0,4]$$",=$)`C_____QT0D!`$```")+"3H<>+__X/&`8/%`@^V!H3`
M=<R-K"38````N/30!`CK"H/%!(M%_(7`="R-5"1<Z.WP__^)QH7`=.>`.`!T
MXNC*\O__A<"0=-B)-"3H=N+__XG"A<!U.HVL)+P```"^.=$$".L/BW4$A?9T
M(X/%!(`^`'0;B?#HD_+__X7`=.:)-"3H0.+__X7`=-J)PNL",=*)%"2)5"0X
MZ(K@__^)QHD<).B`X/__`<:!Q@0$``")-"3H$.'__XE$)#2)7"0<QT0D&%C1
M!`C'1"04=-`$"(M4)#B)5"00QT0D#%W1!`C'1"0(_____\=$)`0!````B<.)
M!"3H?N'__\=$)`3``0``B1PDZ%[>__^#^/]U$.@TWO__BP"#^!$/A7<"``"-
M1"1<B40D!(M$)#2)!"3H]>#__XG#A<!T5HM$)#2)1"00BP>)1"0,QT0D"$#2
M!`C'1"0$`0```*$@,04(B00DZ&3>___'1"0X`````(N$)(R!``!E*P44````
M#X6'"```BT0D.('$G($``%M>7UW#BT0D;"4`\```/0!```!UFHML)'3HP-__
M_SG%=8V+1"1L)?\!```]P`$```^%>?___XDT).@`X/__B40D.(U4)%RX9M$$
M".A([___A<`/A"H"``")!"3HWN#__XE$)`2+!XD$).B.]?__B<:%P`^$"@(`
M`(DT).@>W___B<6#^`-V+<=$)`1KT00(C4#\`?")!"3HTN#__X7`=12#_00/
MA'`&``"`?"[[+P^$908``*$`,04(@_C_#X0W!```A<`/A,D!``"Z*]$$"+BS
MT`0(Z.+Q___H\-S__\=$)!RIT00(B40D&,=$)!1TT`0(BWPD-(E\)!#'1"0,
MA-$$",=$)`C_____QT0D!`$```"+="0XB30DZ-#?___K3NB9W/__@S@1=5F#
MPP'HG-S__\=$)""IT00(B5PD'(E$)!C'1"04=-`$"(E\)!#'1"0,DM$$",=$
M)`C_____QT0D!`$```")-"3H@-___\=$)`3``0``B30DZ&#<__^#^/]TG8M$
M)#2)!"3H;]W__XM\)#B)^KA<T`0(Z!SQ__^)/"3HU_K__^DV_O__C9PDR```
M`+@MT00(ZPJ+0P2%P'0N@\,$C50D7.C+[?__A<!TZ8`X`'3DB00DZ&#?__^)
MQH7`#X5._/__BT,$A<!UTL<$)`T```#H0][__XG#OC+1!`BX4P```.E(_/__
MB40D%(M$)#2)1"00BP>)1"0,QT0D"`32!`C'1"0$`0```*$@,04(B00DZ`/<
M___'1"0X`````.F:_?__B00DB40D-.@J^O__BY0DC($``&4K%10```"+1"0T
M#X41!@``B80DL($``('$G($``%M>7UWIO-[__XLWZ>_]___'!0`Q!0@`````
MQT0D!`````")-"3HB]O__XE$)$B%P`^$&_[__\=$)`P"````QT0D!.[____'
M1"0(_____XG'B00DZ(W>___'1"0(!@```(V$)(P!``")1"0$B3PDZ/+;__^`
MO"2,`0```'4.@+PDC0$``$,/A'@$``#'1"0,`````,=$)`0`````QT0D"```
M``"+1"1(B00DZ#;>___'A"3L`````2-%9\>$)/````")J\WOQX0D]````/[<
MNIC'A"3X````=E0R$,>$)/P```#PX=+#QX0D``$```````#'A"0$`0``````
M`,>$)$@!````````QT0D/`````#'1"1$`````,=$)`@`@```C80DC`$``(E$
M)`2+1"1(B00DZ"_;__^)Q87`#XZ;`0``C40M``'``<`QT@-$)$0/DL*)1"1$
M@_H!@UPD//^+3"0\B80D``$``(GHP>@=`<&)3"0\B8PD!`$``(N4)$@!``"-
MA"2,`0``B40D0(72#X6&````@_T_?E*+3"1`B<N-1<")1"1,C6E`@^#``<6Y
M$````(V\)`@!``")WO.EC80D[````.@;X/__@\-`.=UUW8M,)$R)R,'H!HU0
M`<'B!@%4)$#!X`8IP8G-QT0D#$0```");"0(BT0D0(E$)`2-A"0(`0``B00D
MZ$?:__^)K"1(`0``Z?W^__^X0````"G0.>@/3\6-C"0(`0```=&)PHG/C;0D
MC`$``(/X!'-[]L("=`)FI8/B`70!I(N4)$@!```!PHF4)$@!``"#^D`/A`4"
M``"+A"0``0``B40D1(N$)`0!``")1"0\Z9?^__^-5"1<N+/0!`CHD>K__X7`
M#X1Z_?__#[8`/#`/A&_]__^$P&:0#X1E_?__QP4`,04(`0```.F7^___]L$!
M#X44`P``]\<"````#X7T`@``B='!Z0+SI>ED____BT0D2(D$).BNVO__BT0D
M1,'H`X/@/XU0`<:$!`@!``"`C80D"`$``(T\$(/Z.`^.S`$``+E`````*=%T
M#3'`Q@0'`(/``3G(<O6-A"3L````Z+3>__^Y#@```#'`C;PD"`$``/.KBT0D
M/`_(B80D0`$``(M$)$0/R(F$)$0!``"-A"3L````Z'[>__\/MXPD[````(;I
MBY0D[````(G0P>@8P>H0B)0D4`$``&:)C"11`0``BY0D\`````_*B90D4P$`
M`(N4)/0````/RHF4)%<!``"+E"3X````#\J)E"1;`0``BY0D_`````_*B90D
M7P$``(VT)&,!``")]XVL)%`!``"-G"2+`0``ZP</MD4`@\4!#[;`B40D$,=$
M)`Q3T00(QT0D"/_____'1"0$`0```(D\).A?VO__@\<".=]UR\:$)(L!````
MQT0D'*G1!`B)="08QT0D%'30!`B+1"0TB40D$,=$)`QUT00(QT0D"/_____'
M1"0$`0```(M$)#B)!"3H$-K__^F@^O__*<6-C"2,`0```<B)1"1`C80D[```
M`.A@W?__BX0D``$``(E$)$2+A"0$`0``B40D/.GT_/__BW\$A?\/A)#Y__^)
M/"3H<MC__X/X`P^&?_G__\=$)`1PT00(@^@$`?B)!"3H)-K__X7`#T3WZ6#Y
M__^Y.````"G1,<"#^00/@Z4```#VP0)T`F:K@^$!#X1$_O__JND^_O__@+PD
MC@$``$$/A7K[__^`O"2/`0``0P^%;/O__X"\))`!``!(#X5>^___@+PDD0$`
M`$4/A5#[___'1"0,`@```,=$)`3&____QT0D"/____^+?"1(B3PDZ(;9___'
M1"0(*0```(V$)(P!``")1"0$B3PDZ.O6___'1"0<J=$$"(V$)(P!``")1"08
MZ9_^___WQP$```!U9/?'`@```'55@_D$#X)"____B<N#X_PQTHD$%X/"!#G:
M<O8!U^DJ____#[<.9HD/@\<"@\8"@^H"Z?C\__\/MI0DC`$``(A4)#R($8/'
M`8VT)(T!``"-4/_IS/S__V:K@^D"ZZ2J@^D!ZY;H[-?__U575E.#["QEH10`
M``")1"0<,<"+-?`O!0AEBQX/MD-DB$-EC50D&+B7T`0(Z.7F__^%P'0)@#@Q
M#X1^`@``Z.KO__]EBQ['1"0,"P```,=$)`@!````QT0D!*/1!`B)'"3HQM7_
M_X7`#X3&````BT`,BV@8@SUH004(`0^.LP```+\$````,=OK724`02``/0!!
M```/A(4```#'1"0,`@```,=$)`@`````B50D!&6+!HD$).A3V/__B40D!*%D
M004(BP0XB00DZ!_8__^)PJ%H004(A=)U48U3`8/'!(/#`CG8B=-^0L=$)`P`
M````B5PD"(EL)`1EBP:)!"3H:M;__X7`=!Z+$(M""(G!@>$`!"``@?D`!```
M#X5K____BT(,ZY6A:$$%"(U0_SG:#X0W`0``QT0D#`,```#'1"0(`0```,=$
M)`2HT00(98L&B00DZ-74__^)PX7`="O'1"0(JM$$"(M`#(L`B40D!&6+!HD$
M).C#U/__BT,,BP#V0`I`#X5:`0``QT0D#`,```#'1"0(`0```,=$)`2OT00(
M98L&B00DZ('4__^)PX7`="Z-5"08N&70!`CH5^7__X7`#X0$`0``B40D"(M#
M#(L`B40D!&6+!HD$).A=U/__QT0D"`$```#'1"0$L=$$"&6+!HD$).B"T___
MQT0D",;1!`B)1"0$98L&B00DZ"O4__]EBP;&0&4`C50D&+A<T`0(Z/#D__^)
MPZ-L004(A<!T9\=$)`3``0``B1PDZ!O3__^-4`&#^@%V"8/X$0^%J0```(M$
M)!QE*P44````#X63````@\0L6UY?7<.#^`$/CL#^__^[`0```(EL)`1EBP:)
M!"3HE-/__X/#`3D=:$$%"'_FZ9S^__^A9$$%"(D$).@\\O__B<.C;$$%"(7`
M=8''!"24T@0(Z)#5__^`>`$`#X2`_?__Z7/]__^+0PR+%61!!0B+$HL`Z)_F
M___I_?[__XE$)`1EBP:)!"3HZ]3__^F2_O__Z/'4__^)1"0,B5PD"*%D004(
MBP")1"0$QP0DN-($".@RU?__5E.#[#2+="1`9:$4````B40D+#'`B30DZ"KL
M__\/MA")PX32=!"#P`&`^B\/1-@/MA"$TG7PH0`Q!0B%]@^5P8/X_W1<A<`/
ME<`AP83)=1>+1"0L92L%%`````^%A````(/$-%M>PX`^`'3DQT0D"`0```#'
M1"0$6-$$"(D<).CNU/__A<!UR(M$)"QE*P44````=5")\(/$-%M>Z0'D__^(
M3"0?C50D*+BST`0(Z$GC__^%P`^V3"0?=`L/M@"$P'0$/#!U#\<%`#$%"```
M``#I>O___\<%`#$%"`$```#I9____^CHT___\P\>^U.#[!CH.]?__X'#WV``
M`(N#"`$``(E$)`R+1"0HB40D"(M$)"2)1"0$BT0D((D$).B_T?__@\086\,`
M`/,/'OM3@^P(Z/O6__^!PY]@``"#Q`A;PP``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````#`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$52
M3$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?
M1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,
M7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`55-%4@!365-4
M14T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S
M)7,`4$%42`!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E
M<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z
M.E9%4E-)3TX`,2XP-#4`+64`+2T```!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(`````!P97)L>'-I+F,````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A
M+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N
M86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P
M87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@
M*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G
M;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H
M,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K
M(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D
M;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U
M9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E
M="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J
M/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X
M("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K
M:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E
M;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N
M86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U
M:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@
M/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D
M969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H
M(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E
M;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D
M9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U
M:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y
M<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID
M;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ
M95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T[
M"GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I
M.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E
M<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@
M)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D
M,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI
M7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@
M:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I
M;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L
M;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I
M.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H
M(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN
M="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D
M<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@
M?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@
M*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B
M.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H
M(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[
M4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;
M.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H
M+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L
M("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M
M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I
M;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]
M"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I
M.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D
M<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T
M96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N
M=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP
M+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE
M(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M
M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E
M("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K
M(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P
M;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G
M;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM
M?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A
M<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,[T````!D`````D?__%`$`
M`/"4__]L!0``X);__^P````1E___``$``+"7__\X`0``ZJ+__WP!``"0H___
MY`$``->D__\D`@``4*7__TP"```-IO__C`(``.&G___,`@``1JC___`"``!U
MJ/__"`,``$FI__]``P``3JG__U0#```5J___E`,``#6K__^H`P```:S__^@#
M``!:K___&`0``+:O__\T!```T*___TP$``"UL/__E`0``-2[___P!```[K[_
M_S`%``#8O___G`4``!0``````````7I2``%\"`$;#`0$B`$``!`````<````
M[)7__S$`````1`<($````#`````)EO__!0`````````@````1````.2/___P
M`P````X(1@X,2@\+=`1X`#\:.RHR)")`````:````'"6__\Z"P```$$."(4"
M00X,AP-!#A"&!$$.%(,%1@Z0`P,F"PH.%$'##A!!Q@X,0<<."$'%#@1!"P``
M`&0```"L````9J'__Z8`````00X(A0)!#@R'`T$.$(8$00X4@P5##D`"6@H.
M%$'##A!!Q@X,0<<."$'%#@1!"V\*#A1!PPX00<8.#$''#@A!Q0X$00M'#A1!
MPPX00<8.#$''#@A!Q0X$/````!0!``"DH?__1P$```!!#@B%`D$.#(<#00X0
MA@1!#A2#!48.L`%T"@X40<,.$$'&#@Q!QPX(0<4.!$$+`"0```!4`0``JZ+_
M_WD`````00X(@P)&#I`!`FL*#@A!PPX$00L````\````?`$``/RB__^]````
M`$$."(4"00X,AP-!#A"&!$$.%(,%1@[`(`*E"@X40<,.$$'&#@Q!QPX(0<4.
M!$$+/````+P!``!YH___U`$```!!#@B%`D$.#(<#00X0A@1!#A2#!4,.4`+N
M"@X40<,.$$'&#@Q!QPX(0<4.!$$+`"````#\`0``#:7__V4`````00X(@P)#
M#C`"7PX(0<,.!````!0````@`@``3J7__R\`````0PX@:PX$`#0````X`@``
M9:7__]0`````00X(AP)!#@R&`T$.$(,$1@[`0`*?"@X00<,.#$'&#@A!QPX$
M00L`$````'`"```!IO__!0`````````\````A`(``/*E___'`0```$$."(4"
M00X,AP-!#A"&!$$.%(,%1@[`(0)K"@X40<,.$$'&#@Q!QPX(0<4.!$$+$```
M`,0"``!YI___(``````````\````V`(``(6G___,`````$$."(,"0PX@`F`*
M#@A!PPX$10L"0`H."$'##@1!"TL*#@A!PPX$10M+#@A!PPX$+````!@#```1
MJ/__60,```!!#@B'`D$.#(8#0PY``PD#"@X,0<8."$''#@1!"P``&````$@#
M```ZJ___7`````!##B!D"@X$00L``!0```!D`P``>JO__QH`````0PX@5@X$
M`$0```!\`P``?*O__^4`````00X(AP)!#@R&`T$.$(,$0PY``D0*#A!!PPX,
M0<8."$''#@1%"V`*#A!!PPX,0<8."$''#@1!"U@```#$`P``&:S__Q\+````
M00X(A0)!#@R'`T$.$(8$00X4@P5&#K"#`@.3`@H.%$'##A!!Q@X,0<<."$'%
M#@1!"P-T`@H.%$'##A!!Q@X,0<<."$'%#@1%"P``/````"`$``#<MO__&@,`
M``!!#@B%`D$.#(<#00X0A@1!#A2#!4,.0`-?`@H.%$'##A!!Q@X,0<<."$'%
M#@1!"S@```!@!```MKG__^H`````00X(A@)!#@R#`T,.0`)?"@X,0<,."$'&
M#@1!"W,*#@Q!PPX(0<8.!$4+`"P```"<!```?(___^X!````00X(A0)"#05)
MAP.&!(,%`UH!"L-!QD''0<4,!`1!"QP```#,!```-+K__SX`````10X(@P)#
M#B!T#@A!PPX$````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````UJ8$"+:F!`@!````
M[@(```$``````P```0````H#```!````%`,```\```!Z!```#`````"@!`@-
M````2,\$"!D```#<+@4(&P````0````:````X"X%"!P````$````]?[_;S2"
M!`@%````X(@$"`8````@@P0("@```+$$```+````$````!4``````````P``
M`/0O!0@"````\`$``!0````1````%P````2/!`@1````W(X$"!(````H````
M$P````@```#^__]O3(X$"/___V\!````\/__;Y*-!`@`````````````````
M`````````````````````````````````````````````````````````.0N
M!0@``````````$:@!`A6H`0(9J`$"':@!`B&H`0(EJ`$"*:@!`BVH`0(QJ`$
M"-:@!`CFH`0(]J`$"`:A!`@6H00()J$$"#:A!`A&H00(5J$$"&:A!`AVH00(
MAJ$$"):A!`BFH00(MJ$$",:A!`C6H00(YJ$$"/:A!`@&H@0(%J($"":B!`@V
MH@0(1J($"%:B!`AFH@0(=J($"(:B!`B6H@0(IJ($"+:B!`C&H@0(UJ($".:B
M!`CVH@0(!J,$"!:C!`@FHP0(-J,$"$:C!`A6HP0(9J,$"':C!`B&HP0(EJ,$
M"*:C!`BVHP0(QJ,$"-:C!`CFHP0(]J,$"`:D!`@6I`0(``````````#_____
M_-($"$=#0SH@*%!,1"U,:6YU>"D@,3$N,RXP(#(P,C(P-#(Q("AR96QE87-E
M*0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E
M+F=N=2YP<F]P97)T>0`N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM
M`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN
M`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M
M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````
M````````````````````````````````````````````"P````$````"````
MM($$"+0!```3```````````````!`````````!,````'`````@```,B!!`C(
M`0``)```````````````!``````````F````!P````(```#L@00([`$``"@`
M``````````````0`````````.0````<````"````%(($"!0"```@````````
M```````$`````````$<```#V__]O`@```#2"!`@T`@``[`````8`````````
M!`````0```!1````"P````(````@@P0((`,``,`%```'`````0````0````0
M````60````,````"````X(@$".`(``"Q!``````````````!`````````&$`
M``#___]O`@```)*-!`B2#0``N`````8``````````@````(```!N````_O__
M;P(```!,C@0(3`X``)`````'`````0````0`````````?0````D````"````
MW(X$"-P.```H````!@`````````$````"````(8````)````0@````2/!`@$
M#P``\`$```8````7````!`````@```"/`````0````8`````H`0(`"```"0`
M``````````````0`````````B@````$````&````,*`$"#`@``#P`P``````
M```````0````!````)4````!````!@```""D!`@@)```)BL`````````````
M$`````````";`````0````8```!(SP0(2$\``!@```````````````0`````
M````H0````$````"`````-`$"`!0```P/P`````````````$`````````*D`
M```!`````@```#`/!0@PCP``U```````````````!`````````"W`````0``
M``(````$$`4(!)```.P$``````````````0`````````P0````X````#````
MW"X%"-R>```$```````````````$````!````,T````/`````P```.`N!0C@
MG@``!```````````````!`````0```#9````!@````,```#D+@4(Y)X```@!
M```'``````````0````(````X@````$````#````["\%".R?```(````````
M```````$````!````.<````!`````P```/0O!0CTGP``!`$`````````````
M!`````0```#P`````0````,```#X,`4(^*```!````````````````0`````
M````]@````@````#````(#$%"`BA``!4$``````````````@`````````/L`
M```!````,``````````(H0``*P```````````````0````$````!`````P``
A````````````,Z$```0!``````````````$`````````
